#!/usr/bin/env python

from setuptools import setup, find_packages
from distutils.cmd import Command
try:
    import py2exe
except ImportError:
    py2exe = None

from pyvnc2swf import __version__

py2exe_options = {"dist_dir": "pyvnc2swf-%s-py2exe" % __version__.ver}
py2exe_installer_options = py2exe_options.copy()
py2exe_installer_options["install_subdirs"] = "tcl"

def main():
    setup(
        name = "pyvnc2swf",
        version = __version__.ver,
        packages = find_packages(),
        scripts = ["vnc2swf", "vnc2swf-edit", "vnc2swf-play"],
        package_data = {'': ["*.txt", "*.html"]},
        # install_requires = ["pygame>=1.6", "pymedia>=1.3.5"],
        options = {"py2exe": py2exe_options, "build_installer": py2exe_installer_options},
        console = ["vnc2swf", "vnc2swf-edit", "vnc2swf-play"],
        entry_points = {"distutils.commands": ["build_installer = pyvnc2swf.innosetup:build_installer"]},
        author = "Yusuke Shinyama",
        author_email = "yusuke@cs.nyu.edu",
        maintainer = "David Fraser",
        maintainer_email = "davidf@sjsoft.com",
        license = "GNU General Public License (GPL)",
        keywords = "vnc screencast movie record",
        url = "http://www.unixuser.org/~euske/vnc2swf/pyvnc2swf.html",
        download_url = "http://www.unixuser.org/~euske/vnc2swf/",
        description = "Pyvnc2swf is a cross-platform screen recording tool",
        long_description = "Pyvnc2swf is a cross-platform screen recording tool. It captures screen motion through VNC protocol and generates a Shockwave Flash (SWF) movie.",
        classifiers = [
          "Development Status :: 4 - Beta",
          "Environment :: Console",
          "Environment :: Win32 (MS Windows)",
          "Environment :: X11 Applications",
          "Intended Audience :: End Users/Desktop",
          "License :: OSI Approved :: GNU General Public License (GPL)",
          "Natural Language :: English",
          "Operating System :: OS Independent",
          "Programming Language :: Python",
          "Topic :: Multimedia :: Video :: Capture",
        ],
    )

if __name__ == "__main__":
    main()

